==> template-engine-0.0.1.tgz: package/lib/TemplateServer.js <==
var Class    = require("core").Class;
var Request  = require("core").Net.Request;
var Response = require("core").Net.Response;
var Server   = require("core").Net.Server;
var YAML     = require("core").Yaml.YAML;

var TemplateRequestProcessor = require("./TemplateRequestProcessor.js").TemplateRequestProcessor;
var Cache = require("./cache/Cache.js").Cache;


/**
 * @class Server Main http server class. Wraps native node.js http object. Creates Request processor instance and dispatch processing. 
 * @param {Class} RequestProcessorClass Subclass of RequestProcessor family.
 */
var TemplateServer = function(){
    this.Extends = Server;
    
    this._cache = null;
    this._templatePath = null;
    
    this.initialize = function(){
      
        try {
           this.configuration = YAML.parseFileSync("./bin/conf.yaml").pop();
           this._templatePath = this.configuration.templatePath;
        } catch(e){
           console.log('Configuration file (./bin/conf.yaml) does not exists. Using default template path...')
           this._templatePath = "templates/";
        }
      
        this._cache = new Cache([
            {
                className: "JqTplCache",
                resourcePath: this._templatePath,
                excludePattern: ".svn"
            }
        ]);
        
        try{
          this._cache.cache();
        } catch(e){
          console.log('Cannot cache resources: ' + e.message);
          process.exit(1);
        }
        
        // starting real server
        this.parent(TemplateRequestProcessor);
    };
    
    /**
     * Returns a server template path
     * 
     * @returns {String}
     */
    this.getTemplatePath = function(){
        return this._templatePath;
    };

    /**
     * Sets server template path
     * 
     * @param {string} templatePath Path to templates folder.
     */
    this.setTemplatePath = function(templatePath){
        this._templatePath = templatePath;
    };
    
    
}
TemplateServer.Exception = {};
TemplateServer = new Class(new TemplateServer());
exports.TemplateServer = TemplateServer;

==> template-engine-0.0.3.tgz: package/lib/TemplateServer.js <==
var Class    = require("core").Class;
var Request  = require("core").Net.Request;
var Response = require("core").Net.Response;
var Server   = require("core").Net.Server;
var YAML     = require("core").Yaml.YAML;

var TemplateRequestProcessor = require("./TemplateRequestProcessor.js").TemplateRequestProcessor;
var Cache = require("./cache/Cache.js").Cache;


/**
 * @class Server Main http server class. Wraps native node.js http object. Creates Request processor instance and dispatch processing. 
 * @param {Class} RequestProcessorClass Subclass of RequestProcessor family.
 */
var TemplateServer = function(){
    this.Extends = Server;
    
    this._cache = null;
    this._templatePath = null;
    
    this.initialize = function(){
      
        try {
           this.configuration = YAML.parseFileSync("./bin/conf.yaml").pop();
           this._templatePath = this.configuration.templatePath;
        } catch(e){
           console.log('Configuration file (./bin/conf.yaml) does not exists. Using default template path...')
           this._templatePath = "templates/";
        }
      
        this._cache = new Cache([
            {
                className: "JqTplCache",
                resourcePath: this._templatePath,
                excludePattern: ".svn"
            }
        ]);
        
        try{
          this._cache.cache();
        } catch(e){
          //console.log('Cannot cache resources: ' + e.message);
          process.exit(1);
        }
        
        // starting real server
        this.parent(TemplateRequestProcessor);
    };
    
    /**
     * Returns a server template path
     * 
     * @returns {String}
     */
    this.getTemplatePath = function(){
        return this._templatePath;
    };

    /**
     * Sets server template path
     * 
     * @param {string} templatePath Path to templates folder.
     */
    this.setTemplatePath = function(templatePath){
        this._templatePath = templatePath;
    };
    
    
}
TemplateServer.Exception = {};
TemplateServer = new Class(new TemplateServer());
exports.TemplateServer = TemplateServer;
